package com.ruoyi.system.service;

import java.util.List;
import com.ruoyi.common.core.domain.entity.ColumnNews;

/**
 * 新闻信息Service接口
 * 
 * @author boman
 * @date 2021-12-24
 */
public interface IColumnNewsService 
{
    /**
     * 查询新闻信息
     * 
     * @param newsId 新闻信息主键
     * @return 新闻信息
     */
    public ColumnNews selectColumnNewsByNewsId(Integer newsId);

    /**
     * 门户查询新闻信息
     * @param newsId
     * @return
     */
    public ColumnNews selectColumnNewsDetailMenHu(Integer newsId);

    /**
     * 查询新闻信息列表
     * 
     * @param columnNews 新闻信息
     * @return 新闻信息集合
     */
    public List<ColumnNews> selectColumnNewsList(ColumnNews columnNews);

    /**
     * 查询新闻信息列表门户
     * @param columnNews
     * @return
     */
    public List<ColumnNews> selectColumnNewsListMenHu(ColumnNews columnNews);

    /**
     * 新增新闻信息
     * 
     * @param columnNews 新闻信息
     * @return 结果
     */
    public int insertColumnNews(ColumnNews columnNews);

    /**
     * 修改新闻信息
     * 
     * @param columnNews 新闻信息
     * @return 结果
     */
    public int updateColumnNews(ColumnNews columnNews);

    /**
     * 批量删除新闻信息
     * 
     * @param newsIds 需要删除的新闻信息主键集合
     * @return 结果
     */
    public int deleteColumnNewsByNewsIds(Integer[] newsIds);

    /**
     * 删除新闻信息信息
     * 
     * @param newsId 新闻信息主键
     * @return 结果
     */
    public int deleteColumnNewsByNewsId(Integer newsId);

    /**
     * 审核通过
     * @param newsId
     * @return
     */
    public int examineColumnNews(Integer newsId);

    /**
     * 获取首页轮播图
     * @return
     */
    public List<ColumnNews> getRotation();
}
